@@ -1,5 +1,5 @@
 /*
- *		Copyright (C) 2013, 2014 by the Konclude Developer Team.
+ *		Copyright (C) 2013, 2014, 2015 by the Konclude Developer Team.
  *
  *		This file is part of the reasoning system Konclude.
  *		For details and support, see <http://konclude.com/>.
@@ -1105,6 +1105,10 @@ namespace Konclude {
 						new CBooleanConfigType(false)),
 						new CBooleanConfigType(false));
 
+				addConfigProperty(new CConfigDescription("Konclude.Test.Generator.GenerateRealizeTests",
+						"Determines whether realization tests are generated.",
+						new CBooleanConfigType(false)),
+						new CBooleanConfigType(false));
 
 
 
